summaryrefslogtreecommitdiffstats
path: root/webkit/glue/webkit_glue.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/glue/webkit_glue.h')
-rw-r--r--webkit/glue/webkit_glue.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/webkit/glue/webkit_glue.h b/webkit/glue/webkit_glue.h
index 50cd2c4..a3c4d2c 100644
--- a/webkit/glue/webkit_glue.h
+++ b/webkit/glue/webkit_glue.h
@@ -105,9 +105,10 @@ std::string GetWebKitVersion();
// inconsistent behavior.
void SetUserAgent(const std::string& new_user_agent);
-// Returns the user agent, which is usually the default user agent but may be
-// overriden by a call to SetUserAgent() (which should be done at startup).
-const std::string& GetUserAgent();
+// Returns the user agent to use for the given URL, which is usually the
+// default user agent but may be overriden by a call to SetUserAgent() (which
+// should be done at startup).
+const std::string& GetUserAgent(const GURL& url);
// Creates serialized state for the specified URL. This is a variant of
// HistoryItemToString (in glue_serialize) that is used during session restore